==> apache-shenyu-2.5.1-src.zip: apache-shenyu-2.5.1-src/shenyu-common/src/main/java/org/apache/shenyu/common/timer/TimerTask.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shenyu.common.timer;

import java.util.concurrent.TimeUnit;

/**
 * TimerTask.
 */
public abstract class TimerTask {
    
    /**
     * The time the current task delays execution ms.
     */
    private final long delayMs;
    
    private TimerTaskList.TimerTaskEntry timerTaskEntry;
    
    /**
     * Instantiates a new Timer task.
     *
     * @param delayMs the delay ms
     */
    public TimerTask(final long delayMs) {
        this(delayMs, TimeUnit.MILLISECONDS);
    }
    
    /**
     * Instantiates a new Timer task.
     *
     * @param delay the delay
     * @param unit  the unit
     */
    public TimerTask(final long delay, final TimeUnit unit) {
        delayMs = unit.toMillis(delay);
    }
    
    /**
     * Sets timer task entry.
     *
     * @param entry the entry
     */
    synchronized void setTimerTaskEntry(final TimerTaskList.TimerTaskEntry entry) {
        if (timerTaskEntry != null && timerTaskEntry != entry) {
            this.timerTaskEntry.remove();
        }
        timerTaskEntry = entry;
    }
    
    /**
     * Gets delay ms.
     *
     * @return the delay ms
     */
    long getDelayMs() {
        return delayMs;
    }
    
    /**
     * Gets timer task entry.
     *
     * @return the timer task entry
     */
    TimerTaskList.TimerTaskEntry getTimerTaskEntry() {
        return timerTaskEntry;
    }
    
    /**
     * Cancel task.
     */
    public synchronized void cancel() {
        if (timerTaskEntry != null) {
            timerTaskEntry.remove();
        }
        timerTaskEntry = null;
    }
    
    /**
     * Run.
     *
     * @param taskEntity the task entity
     */
    public abstract void run(TaskEntity taskEntity);
}

==> apache-shenyu-2.6.1-src.zip: apache-shenyu-2.6.1-src/shenyu-common/src/main/java/org/apache/shenyu/common/timer/TimerTask.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shenyu.common.timer;

import java.util.Objects;
import java.util.concurrent.TimeUnit;

/**
 * TimerTask.
 */
public abstract class TimerTask {

    /**
     * The time the current task delays execution ms.
     */
    private final long delayMs;

    private TimerTaskList.TimerTaskEntry timerTaskEntry;

    /**
     * Instantiates a new Timer task.
     *
     * @param delayMs the delay ms
     */
    public TimerTask(final long delayMs) {
        this(delayMs, TimeUnit.MILLISECONDS);
    }

    /**
     * Instantiates a new Timer task.
     *
     * @param delay the delay
     * @param unit  the unit
     */
    public TimerTask(final long delay, final TimeUnit unit) {
        delayMs = unit.toMillis(delay);
    }

    /**
     * Sets timer task entry.
     *
     * @param entry the entry
     */
    synchronized void setTimerTaskEntry(final TimerTaskList.TimerTaskEntry entry) {
        if (Objects.nonNull(timerTaskEntry) && timerTaskEntry != entry) {
            this.timerTaskEntry.remove();
        }
        timerTaskEntry = entry;
    }

    /**
     * Gets delay ms.
     *
     * @return the delay ms
     */
    long getDelayMs() {
        return delayMs;
    }

    /**
     * Gets timer task entry.
     *
     * @return the timer task entry
     */
    TimerTaskList.TimerTaskEntry getTimerTaskEntry() {
        return timerTaskEntry;
    }

    /**
     * Cancel task.
     */
    public synchronized void cancel() {
        if (Objects.nonNull(timerTaskEntry)) {
            timerTaskEntry.remove();
        }
        timerTaskEntry = null;
    }

    /**
     * Run.
     *
     * @param taskEntity the task entity
     */
    public abstract void run(TaskEntity taskEntity);
}
